NLSL: mspctr.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

mspctr.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/12/15
2 c----------------------------------------------------------------------
3 c =========================
4 c module MSPCTR
5 c =========================
6 c Defines working arrays used for multiple-site spectral fitting
7 c
8 c Note: module nlsdim is used by this module
9 c
10 c spectr Storage for calculated spectra for each site, spectrum
11 c
12 c wspec Work array for temporary storage of calculated spectra
13 c Used by sshift to store correlation function for each
14 c spectrum
15 c Used before call to sscale (array is replaced by QR
16 c decomposition)
17 c
18 c sfac Scale factors for each site and spectrum
19 c
20 c iscal Flag indicating whether each site is to be automatically
21 c scaled in the function calculation (1=auto scale)
22 c
23 c iscglb Flag indicating whether all sites are to be automatically
24 c scaled (1=auto scale)
25 c
26 c----------------------------------------------------------------------
27 c
28 module mspctr
29 use nlsdim
30 implicit none
31 c
32 integer, save :: iscal(mxsite), iscglb
33 double precision, save ::
34 # spectr(mxpt,mxsite), wspec(mxpt,mxsite), sfac(mxsite,mxspc)
35 c
36 end module mspctr
37
nlsdim::mxpt
integer, parameter mxpt
Definition: nlsdim.f90:39
mspctr::iscglb
integer, save iscglb
Definition: mspctr.f90:32
mspctr::wspec
double precision, dimension(mxpt, mxsite), save wspec
Definition: mspctr.f90:33
mspctr::sfac
double precision, dimension(mxsite, mxspc), save sfac
Definition: mspctr.f90:33
nlsdim::mxspc
integer, parameter mxspc
Definition: nlsdim.f90:39
mspctr::iscal
integer, dimension(mxsite), save iscal
Definition: mspctr.f90:32
nlsdim::mxsite
integer, parameter mxsite
Definition: nlsdim.f90:39
nlsdim
Definition: nlsdim.f90:36
mspctr
Definition: mspctr.f90:28
mspctr::spectr
double precision, dimension(mxpt, mxsite), save spectr
Definition: mspctr.f90:33